@@ -1,16 +1,18 @@
 import streamlit as st
 from manager import PromptManager
 from openai import OpenAI
+from streamlit_ace import st_ace
 
 
-def init_session_state():
-    """Initialize session state variables"""
+def init_session_state():  # noqa: ANN201
+    """Initialize session state variables."""
     if "show_delete_confirm" not in st.session_state:
         st.session_state.show_delete_confirm = False
         st.session_state.version_to_delete = None
 
         oai_client = OpenAI(
-            base_url="http://localhost:9999/v1",
+            # base_url="http://localhost:9999/v1",  # noqa: ERA001
+            base_url="http://localhost:11434/v1",
             api_key="empty",
         )
         st.session_state.oai_client = oai_client
@@ -97,37 +99,35 @@ def add_one_multimodal_message(message, i):
                      "image_url": "https://"}
                 ]
 
-            def add_mm_content():
-                # 显示一个列表输入区域，一个text 一个 image_url
-                for idx, _content in enumerate(message['content']):
-                    if _content['type'] == "text":
-                        st.text_area(
-                            "text",
-                            value=_content['text'],
-                            key=f"multimodal_text_{i}_{idx}",
-                            placeholder="请输入文本",
-                            on_change=update_multimodal_message_content,
-                            args=(i, 'text', idx),
-                        )
-                    else:
-                        cols_inner = st.columns([0.2, 0.70, 0.1])
-                        # with cols_inner[0]:
-                        #     _content["type"] = st.selectbox(
-                        #         "媒体类型",
-                        #         options=['image_url', "video_url", "image"],
-                        #         key=f"multimodal_text_{i}_idx",
-                        #         index=0,
-                        #     )
-                        st.text_area(
-                            "image_url",
-                            value=_content['image_url'],
-                            key=f"multimodal_image_url_{i}_{idx}",
-                            placeholder="请输入图片url",
-                            on_change=update_multimodal_message_content,
-                            args=(i, 'image_url', idx),
-                        )
+            # 显示一个列表输入区域，一个text 一个 image_url
+            for idx, _content in enumerate(message['content']):
+                if _content['type'] == "text":
+                    st.text_area(
+                        "text",
+                        value=_content['text'],
+                        key=f"multimodal_text_{i}_{idx}",
+                        placeholder="请输入文本",
+                        on_change=update_multimodal_message_content,
+                        args=(i, 'text', idx),
+                    )
+                else:
+                    # cols_inner = st.columns([0.2, 0.70, 0.1])
+                    st.text_area(
+                        "image_url",
+                        value=_content['image_url'],
+                        key=f"multimodal_image_url_{i}_{idx}",
+                        placeholder="请输入图片url",
+                        on_change=update_multimodal_message_content,
+                        args=(i, 'image_url', idx),
+                    )
+                    # content = st_ace(
+                    #     height=50,
+                    #     placeholder="请输入图片url",
+                    #     language="python",
+                    #     # theme="monokai",
+                    #     # key=f"multimodal_image_url_{i}_{idx}",
+                    # )
 
-            add_mm_content()
         else:
             st.text_area(
                 "content",
@@ -220,20 +220,20 @@ def render_prompt_creation(pm):
     is_multimodal_prompt = st.toggle("多模态prompt", value=False)
     st.write("### messages")
 
-    "---"
-    "### 尚未完成"
-    "---"
     st.session_state.messages[0]["content"] = st.text_area(
         "System Content",
         value=st.session_state.messages[0]["content"],
         key="system",
     )
     for i, message in enumerate(st.session_state.messages[1:], 1):
-        add_one_multimodal_message(message, i)
+        if is_multimodal_prompt:
+            add_one_multimodal_message(message, i)
+        else:
+            add_one_message(message, i)
 
     # Add message button
     if st.button("添加角色消息", use_container_width=True):
-        add_message(multimodal=True)
+        add_message(multimodal=is_multimodal_prompt)
         st.rerun()
 
     prompt_tags = st.text_input("标签 (用逗号分隔)", key="tags", value="v0.1,dev,效果优化")
@@ -241,6 +241,7 @@ def render_prompt_creation(pm):
 
     if st.button("保存该版本", use_container_width=True, icon="🔥"):
         save_prompt_data(prompt_name, st.session_state.messages, prompt_tags, commit_comment)
+    return is_multimodal_prompt
 
 
 def render_prompt_delete(pm):
@@ -448,23 +449,66 @@ def render_ai_history():
             st.write(message["content"])
 
 
-def render_debug_section():
+def render_debug_section(is_multimodal: bool):
     """Render debug section"""
     st.header("Prompt 调试区")
+    _the_last_msg = st.session_state.messages[-1]
+    print(f"{_the_last_msg=}")
 
+    input_var = "user_input"
+
+    prompt_str = f"{{{input_var}}}"
+
+    def add_content_to_msg(content):
+        if not is_multimodal:
+            st.session_state.messages.append({
+                "role": "user",
+                "content": content
+            })
+        else:
+            st.session_state.messages.append({
+                "role": "user",
+                "content": [
+                    {"type": "text", "text": content},
+                ]
+            })
+
+    if _the_last_msg['role'] not in ('user', 'mm_user'):
+        add_content_to_msg(prompt_str)
+
+
+    def get_prompt_str(content):
+        prompt_str = f"{{{input_var}}}"
+        if isinstance(content, str):
+            if input_var in content:
+                prompt_str = content
+        elif isinstance(content, list):
+            for i in content:
+                if i['type'] == 'text':
+                    if input_var in i['text']:
+                        prompt_str = i['text']
+        else:
+            raise
+        return prompt_str
+
+    the_last_msg = st.session_state.messages.pop()
     if st.toggle("追加至prompt历史", value=False):
         if prompt := st.chat_input("测试输入"):
+            prompt_str = get_prompt_str(the_last_msg['content'])
             render_ai_history()
-            st.session_state.messages.append({"role": "user", "content": prompt})
             with st.chat_message("user"):
-                st.write(prompt)
+                content = prompt_str.format(**{input_var: prompt})
+                st.write(content)
+            add_content_to_msg(content)
             render_ai_response(st.session_state.messages, append_to_history=True)
     elif prompt := st.chat_input("测试输入"):
+        prompt_str = get_prompt_str(the_last_msg['content'])
         render_ai_history()
-        messages = [{"role": "user", "content": prompt}]
         with st.chat_message("user"):
-            st.write(prompt)
-        render_ai_response(st.session_state.messages + messages, append_to_history=False)
+            content = prompt_str.format(**{input_var: prompt})
+            st.write(content)
+        add_content_to_msg(content)
+        render_ai_response(st.session_state.messages, append_to_history=False)
 
 
 def main():
@@ -477,8 +521,8 @@ def main():
     if mode == "配置模型参数":
         set_model()
     elif mode == "创建或更新 Prompt":
-        render_prompt_creation(pm)
-        render_debug_section()
+        is_multimodal_prompt = render_prompt_creation(pm)
+        render_debug_section(is_multimodal_prompt)
     elif mode == "加载已有 Prompt":
         render_prompt_loading(pm)
     else:
